summaryrefslogtreecommitdiffstats
path: root/cmakemodules/FindKdeLibs.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmakemodules/FindKdeLibs.cmake')
-rw-r--r--cmakemodules/FindKdeLibs.cmake16
1 files changed, 8 insertions, 8 deletions
diff --git a/cmakemodules/FindKdeLibs.cmake b/cmakemodules/FindKdeLibs.cmake
index 85d6c2a..356c0e4 100644
--- a/cmakemodules/FindKdeLibs.cmake
+++ b/cmakemodules/FindKdeLibs.cmake
@@ -7,7 +7,7 @@ include(FindQt3)
# KDE3_INCLUDE_DIR - the KDE include directory
# KDE3_INCLUDE_DIRS - the KDE and the Qt include directory, for use with INCLUDE_DIRECTORIES()
# KDE3_LIB_DIR - the directory where the KDE libraries are installed, for use with LINK_DIRECTORIES()
# QT_AND_KDECORE_LIBS - this contains both the Qt and the tdecore library
# KDE3_DCOPIDL_EXECUTABLE - the dcopidl executable
# KDE3_DCOPIDL2CPP_EXECUTABLE - the dcopidl2cpp executable
# KDE3_KCFGC_EXECUTABLE - the kconfig_compiler executable
@@ -55,7 +55,7 @@ include(FindQt3)
# If WITH_PREFIX is given, the resulting plugin will have the prefix "lib", otherwise it won't.
# It creates and installs an appropriate libtool la-file.
#
-# KDE3_ADD_KDEINIT_EXECUTABLE(name file1 ... fileN )
+# KDE3_ADD_TDEINIT_EXECUTABLE(name file1 ... fileN )
# Create a KDE application in the form of a module loadable via tdeinit.
# A library named tdeinit_<name> will be created and a small executable which links to it.
#
@@ -139,7 +139,7 @@ FIND_PATH(KDE3_INCLUDE_DIR kpassdlg.h
# SET(KDE3_INCLUDE_DIR "/usr/include/kde")
#now the KDE library directory
-FIND_LIBRARY(KDE3_KDECORE_LIBRARY NAMES tdecore
+FIND_LIBRARY(KDE3_TDECORE_LIBRARY NAMES tdecore
HINTS
$ENV{KDEDIR}/lib
${KDE3PREFIX}/lib
@@ -150,16 +150,16 @@ FIND_LIBRARY(KDE3_KDECORE_LIBRARY NAMES tdecore
/usr/trinity/lib
)
-SET(QT_AND_KDECORE_LIBS ${QT_LIBRARIES} ${KDE3_KDECORE_LIBRARY})
+SET(QT_AND_TDECORE_LIBS ${QT_LIBRARIES} ${KDE3_TDECORE_LIBRARY})
-GET_FILENAME_COMPONENT(KDE3_LIB_DIR ${KDE3_KDECORE_LIBRARY} PATH )
+GET_FILENAME_COMPONENT(KDE3_LIB_DIR ${KDE3_TDECORE_LIBRARY} PATH )
IF(NOT KDE3_LIBTOOL_DIR)
- IF(KDE3_KDECORE_LIBRARY MATCHES lib64)
+ IF(KDE3_TDECORE_LIBRARY MATCHES lib64)
SET(KDE3_LIBTOOL_DIR /lib64/trinity)
- ELSE(KDE3_KDECORE_LIBRARY MATCHES lib64)
+ ELSE(KDE3_TDECORE_LIBRARY MATCHES lib64)
SET(KDE3_LIBTOOL_DIR /lib/trinity)
- ENDIF(KDE3_KDECORE_LIBRARY MATCHES lib64)
+ ENDIF(KDE3_TDECORE_LIBRARY MATCHES lib64)
ENDIF(NOT KDE3_LIBTOOL_DIR)
#now search for the dcop utilities
@@ -7,7 +7,7 @@ include(FindQt3)
# KDE3_INCLUDE_DIRS - the KDE and the Qt include directory, for use with INCLUDE_DIRECTORIES()
# KDE3_LIB_DIR - the directory where the KDE libraries are installed, for use with LINK_DIRECTORIES()
-# QT_AND_KDECORE_LIBS - this contains both the Qt and the tdecore library
+# QT_AND_TDECORE_LIBS - this contains both the Qt and the tdecore library
# KDE3_DCOPIDL_EXECUTABLE - the dcopidl executable
# KDE3_DCOPIDL2CPP_EXECUTABLE - the dcopidl2cpp executable